AvatarBackgroundGradient enum

Enum representing different background gradient styles for the avatar.

Inheritance
Available extensions

Values

sunsetPastels → const AvatarBackgroundGradient

A gradient with pastel sunset colors.

oceanDepths → const AvatarBackgroundGradient

A gradient with deep ocean colors.

tropicalSunset → const AvatarBackgroundGradient

A gradient with tropical sunset colors.

forestHues → const AvatarBackgroundGradient

A gradient with various shades of green representing a forest.

warmHorizon → const AvatarBackgroundGradient

A gradient with warm, horizon-like colors.

Properties

gradient → Gradient

Available on AvatarBackgroundGradient, provided by the AvatarBackgroundGradientExtension extension

Returns the Gradient associated with the selected AvatarBackgroundGradient.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AvatarBackgroundGradient>
A constant List of the values in this enum, in order of their declaration.